@@ -1,5 +1,6 @@
 mod entries;
 mod footer;
+mod glob;
 mod header;
 mod help;
 mod main;
@@ -7,6 +8,7 @@ mod mark;
 
 pub use entries::*;
 pub use footer::*;
+pub use glob::*;
 pub use header::*;
 pub use help::*;
 pub use main::*;
