@@ -1,7 +1,7 @@
 #![forbid(rust_2018_idioms, unsafe_code)]
 use anyhow::Result;
 use clap::{CommandFactory as _, Parser};
-use dua::{canonicalize_ignore_dirs, TraversalSorting};
+use dua::{TraversalSorting, canonicalize_ignore_dirs};
 use log::info;
 use simplelog::{Config, LevelFilter, WriteLogger};
 use std::fs::OpenOptions;
@@ -59,14 +59,13 @@ fn main() -> Result<()> {
         walk_options.threads = num_cpus::get();
     }
 
+    let cross_filesystems = walk_options.cross_filesystems;
+
     let res = match opt.command {
         #[cfg(feature = "tui-crossplatform")]
-        Some(Interactive {
-            no_entry_check,
-            input,
-        }) => {
-            use anyhow::{anyhow, Context};
-            use crosstermion::terminal::{tui::new_terminal, AlternateRawScreen};
+        Some(Interactive { no_entry_check }) => {
+            use anyhow::{Context, anyhow};
+            use crosstermion::terminal::{AlternateRawScreen, tui::new_terminal};
 
             let no_tty_msg = "Interactive mode requires a connected terminal";
             if atty::isnt(atty::Stream::Stderr) {
@@ -84,7 +83,7 @@ fn main() -> Result<()> {
                 walk_options,
                 byte_format,
                 !no_entry_check,
-                extract_paths_maybe_set_cwd(input, !opt.stay_on_filesystem)?,
+                extract_paths_maybe_set_cwd(opt.input, cross_filesystems)?,
             )?;
             app.traverse()?;
 
@@ -120,7 +119,6 @@ fn main() -> Result<()> {
             );
         }
         Some(Aggregate {
-            input,
             no_total,
             no_sort,
             statistics,
@@ -134,7 +132,7 @@ fn main() -> Result<()> {
                 !no_total,
                 !no_sort,
                 byte_format,
-                extract_paths_maybe_set_cwd(input, !opt.stay_on_filesystem)?,
+                extract_paths_maybe_set_cwd(opt.input, cross_filesystems)?,
             )?;
             if statistics {
                 writeln!(io::stderr(), "{stats:?}").ok();
@@ -157,7 +155,7 @@ fn main() -> Result<()> {
                 true,
                 true,
                 byte_format,
-                extract_paths_maybe_set_cwd(opt.input, !opt.stay_on_filesystem)?,
+                extract_paths_maybe_set_cwd(opt.input, cross_filesystems)?,
             )?
             .0
         }
@@ -201,10 +199,10 @@ fn cwd_dirlist() -> Result<Vec<PathBuf>, io::Error> {
                 .and_then(|e| e.path().strip_prefix(".").ok().map(ToOwned::to_owned))
         })
         .filter(|p| {
-            if let Ok(meta) = p.symlink_metadata() {
-                if meta.file_type().is_symlink() {
-                    return false;
-                }
+            if let Ok(meta) = p.symlink_metadata()
+                && meta.file_type().is_symlink()
+            {
+                return false;
             };
             true
         })
